@@ -1,6 +1,6 @@
 package PMLTQ::Command::delete;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Command::delete::VERSION = '1.2.3';
+$PMLTQ::Command::delete::VERSION = '1.3.0';
 # ABSTRACT: Deletes the treebank from database
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -12,8 +12,11 @@ sub run {
   my $config = $self->config;
 
   my $dbh = $self->sys_db;
-  $dbh->do("DROP DATABASE \"$config->{db}->{name}\";") or die $dbh->errstr;
+  $dbh->do("SELECT pg_terminate_backend(pg_stat_activity.pid) FROM pg_stat_activity WHERE pg_stat_activity.datname = '$config->{db}->{name}' AND pid <> pg_backend_pid();"); # disconnect all connections to deleted database
+  $dbh->do("DROP DATABASE \"$config->{db}->{name}\";");
+  my $error = $dbh->errstr;
   $dbh->disconnect;
+  die $error if $error;
 }
 
 
@@ -31,7 +34,7 @@ PMLTQ::Command::delete - Deletes the treebank from database
 
 =head1 VERSION
 
-version 1.2.3
+version 1.3.0
 
 =head1 SYNOPSIS
 
