@@ -1,6 +1,6 @@
 package PMLTQ::Command::init;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Command::init::VERSION = '1.2.3';
+$PMLTQ::Command::init::VERSION = '1.3.0';
 # ABSTRACT: Initialize empty database
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -76,6 +76,7 @@ sub run {
     push @layers, {
       name       => $schema->get_root_name,
       data       => '<change this to point to files relative to the data_dir>',
+      path       => '<change this to point to files relative to the data directory on server>',
       references => {%$refs}
       };
   }
@@ -105,7 +106,17 @@ sub run {
       treebank_id => $treebank_id,
       title       => $treebank_title,
       resources   => $resources_dir,
-      layers      => \@layers
+      layers      => \@layers,
+      description => '',
+      isPublic      => 'false',
+      isFree        => 'false',
+      isFeatured    => 'false',
+      web_api     =>
+        {
+          url      => '',
+          user     => '',
+          password => ''
+        }
     }
   );
 
@@ -190,7 +201,7 @@ PMLTQ::Command::init - Initialize empty database
 
 =head1 VERSION
 
-version 1.2.3
+version 1.3.0
 
 =head1 SYNOPSIS
 
